@@ -82,10 +82,7 @@ struct AtomicFile::impl
   static atomic_files_t atomic_files;
 };
 
-using atomic_files_t = AtomicFile::impl::atomic_files_t;
-using atomics_iterator = atomic_files_t::iterator;
-
-atomic_files_t AtomicFile::impl::atomic_files {};
+AtomicFile::impl::atomic_files_t AtomicFile::impl::atomic_files {};
 bool AtomicFile::impl::allow_atomics {true};
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -282,27 +279,19 @@ void AtomicFile::impl::finalize ()
   }
 }
 
-////////////////////////////////////////////////////////////////////////////////
-atomics_iterator AtomicFile::impl::find (const Path& path)
-{
-  auto end = impl::atomic_files.end ();
-  auto cmp = [&path](const atomic_files_t::value_type& p)
-             {
-               return p->real_file == path;
-             };
-  auto it = std::find_if(impl::atomic_files.begin (), end, cmp);
-  return (it == end) ? end : it;
-}
-
-
 ////////////////////////////////////////////////////////////////////////////////
 AtomicFile::AtomicFile (const Path& path)
 {
-  auto it = impl::find (path);
+  auto end = impl::atomic_files.end ();
+  auto it = std::find_if (impl::atomic_files.begin (), end,
+                          [&path] (const impl::value_type& p)
+                          {
+                            return p->real_file == path;
+                          });
 
-  if (it == impl::atomic_files.end ())
+  if (it == end)
   {
-    pimpl = std::make_shared <impl> (path._data);
+    pimpl = std::make_shared <impl> (path);
     impl::atomic_files.push_back (pimpl);
   }
   else
@@ -403,18 +392,6 @@ void AtomicFile::write_raw (const std::string& content)
   pimpl->write_raw (content);
 }
 
-////////////////////////////////////////////////////////////////////////////////
-void AtomicFile::append (const std::string& path, const std::string& data)
-{
-  return AtomicFile(path).append (data);
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void AtomicFile::write (const std::string& path, const std::string& data)
-{
-  AtomicFile::write (Path (path), data);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 void AtomicFile::write (const Path& path, const std::string& data)
 {
@@ -437,14 +414,7 @@ void AtomicFile::write (const Path& path, const std::vector <std::string>& lines
 ////////////////////////////////////////////////////////////////////////////////
 void AtomicFile::read (const Path& path, std::string& content)
 {
-  AtomicFile file (path);
-  file.read (content);
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void AtomicFile::read (const std::string& path, std::string& content)
-{
-  AtomicFile::read (Path (path), content);
+  AtomicFile (path).read (content);
 }
 
 void AtomicFile::read (const Path& path, std::vector <std::string>& lines)
@@ -483,7 +453,7 @@ void AtomicFile::finalize_all ()
   sigprocmask (SIG_SETMASK, &old_mask, nullptr);
 
   // Step 3: Cleanup any references
-  atomic_files_t new_atomic_files;
+  impl::atomic_files_t new_atomic_files;
   for (auto& file : impl::atomic_files)
   {
     // Delete entry if we are holding the last reference
