@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2018 - 2021, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2018 - 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -30,6 +30,9 @@
 #include <timew.h>
 #include <iostream>
 #include <stdlib.h>
+#include <IntervalFilterAllWithIds.h>
+#include <IntervalFilterAllInRange.h>
+#include <IntervalFilterFirstOf.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdAnnotate (
@@ -49,29 +52,49 @@ int CmdAnnotate (
 
   if (ids.empty ())
   {
-    auto latest = getLatestInterval (database);
+    IntervalFilterFirstOf filtering {std::make_shared <IntervalFilterAllInRange> (Range {})};
+    intervals = getTracked (database, rules, filtering);
 
-    if (latest.empty ())
+    if (intervals.empty ())
     {
       throw std::string ("There is no active time tracking.");
     }
-    else if (!latest.is_open ())
+    else if (!intervals.at (0).is_open ())
     {
       throw std::string ("At least one ID must be specified. See 'timew help annotate'.");
     }
-
-    intervals.push_back (latest);
   }
   else
   {
-    intervals = getIntervalsByIds (database, rules, ids);
+    auto filtering = IntervalFilterAllWithIds (ids);
+    intervals = getTracked (database, rules, filtering);
+
+    if (intervals.size () != ids.size ())
+    {
+      for (auto& id: ids)
+      {
+        bool found = false;
+
+        for (auto& interval: intervals)
+        {
+          if (interval.id == id)
+          {
+            found = true;
+            break;
+          }
+        }
+        if (!found)
+        {
+          throw format ("ID '@{1}' does not correspond to any tracking.", id);
+        }
+      }
+    }
   }
 
   // Apply annotation to intervals.
   for (const auto& interval : intervals)
   {
     Interval modified {interval};
-
     modified.setAnnotation (annotation);
 
     database.modifyInterval (interval, modified, verbose);
