@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2019, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2019, 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,12 +27,11 @@
 #include <commands.h>
 #include <Table.h>
 #include <iostream>
+#include <paths.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 // Enumerate all extensions.
-int CmdExtensions (
-  Rules& rules,
-  const Extensions& extensions)
+int CmdExtensions (const Extensions& extensions)
 {
   Table t;
   t.width (1024);
@@ -59,8 +58,7 @@ int CmdExtensions (
     t.set (row, 1, perms);
   }
 
-  Directory extDir (rules.get ("temp.db"));
-  extDir += "extensions";
+  Directory extDir (paths::extensionsDir ());
 
   std::cout << '\n'
             << "Extensions located in:\n"
